@@ -3,16 +3,17 @@
 #   \__, || (__ |  __/| (__ | |   |  __/| (_| || | | | | |
 #   |___/  \___| \___| \___||_|    \___| \__,_||_| |_| |_|
 #                       sweeter debugging and benchmarking
-#
-#      See https://github.com/salabim/ycecream for details
 
-__version__ = "1.1.6"
+__version__ = "1.1.9"
 
 """
-Inspired by IceCream "Never use print() to debug again"
-Original author: Ansgar Grunseid / grunseid.com / grunseid@gmail.com
+See https://github.com/salabim/ycecream for details
 
 (c)2021 Ruud van der Ham - rt.van.der.ham@gmail.com
+
+Inspired by IceCream "Never use print() to debug again". 
+Also contains some of the original code.
+IceCream was written by Ansgar Grunseid / grunseid.com / grunseid@gmail.com
 """
 
 import inspect
@@ -20,12 +21,15 @@ import sys
 import datetime
 import time
 import textwrap
-from pathlib import Path
+import pathlib
 import contextlib
 import functools
 import json
 import logging
 import collections
+import numbers
+
+Path = pathlib.Path
 
 
 class default:
@@ -88,6 +92,7 @@ def set_defaults():
     default.wrap_indent = "    "
     default.context_delimiter = " ==> "
     default.pair_delimiter = ", "
+    default.values_only = False
 
     ycecream_name = Path(__file__).stem
     config = {}
@@ -97,8 +102,8 @@ def set_defaults():
             with open(path / f"{ycecream_name}.json", "r") as f:
                 config = json.load(f)
             break
-        if (path / "ycecream_name" / f"{ycecream_name}.json").is_file():
-            with open(path / {ycecream_name} / f"{ycecream_name}.json", "r") as f:
+        if (path / f"{ycecream_name}" / f"{ycecream_name}.json").is_file():
+            with open(path / f"{ycecream_name}" / f"{ycecream_name}.json", "r") as f:
                 config = json.load(f)
             break
 
@@ -112,7 +117,9 @@ def set_defaults():
             raise ValueError(f"error in {path}: key {k} not recognized")
 
 
-def no_source_error():
+def no_source_error(s=None):
+    if s is not None:
+        print(s)  # for debugging only
     raise NotImplementedError(
         """
 Failed to access the underlying source code for analysis. Possible causes:
@@ -135,7 +142,13 @@ def check_output(output):
         pass
     raise ValueError("output should be a callable, str, Path or open text file.")
 
-
+def return_args(args):
+    if len(args) == 0:
+        return None
+    if len(args) == 1:
+        return args[0]
+    return args
+    
 class Y:
     def __init__(
         self,
@@ -156,7 +169,8 @@ class Y:
         depth=None,
         wrap_indent=None,
         context_delimiter=None,
-        pair_delimiter=None
+        pair_delimiter=None,
+        values_only=None
     ):
         assign(self, locals(), default)
         check_output(self.output)
@@ -182,6 +196,7 @@ class Y:
         wrap_indent=None,
         context_delimiter=None,
         pair_delimiter=None,
+        values_only=None,
         as_str=False
     ):
 
@@ -189,103 +204,122 @@ class Y:
 
         kwargs = {}
         assign(kwargs, locals(), self)
+        
         this = Y(**kwargs)
+        if (this.enabled == [] or global_enabled == []) and not as_str:
+            return return_args(args)        
+        this.start_time = self.start_time
 
         check_output(this.output)
-        call_frame = inspect.currentframe().f_back
-        filename = call_frame.f_code.co_filename
 
-        if Path(filename).resolve() == main_file_resolved:
-            filename_name = ""
-        else:
-            filename_name = f"[{Path(filename).name}]"
-        if filename not in codes:
-            frame_info = inspect.getframeinfo(call_frame, context=1000000)  # get the full source code
-            if frame_info.code_context is None:
-                no_source_error()
-            codes[filename] = frame_info.code_context
-        code = codes[filename]
-        frame_info = inspect.getframeinfo(call_frame, context=1)
-        parent_function = frame_info.function
-        if parent_function == "<module>":
-            parent_function = ""
-        else:
-            parent_function = f" in {parent_function}()"
-        line_number = frame_info.lineno
-        this_line = code[line_number - 1].strip()
-        this_line_prev = code[line_number - 2].strip()
-        if this_line.startswith("@") or this_line_prev.startswith("@"):
-            if as_str:
-                raise TypeError("as_str may not be True when y used as decorator")
-            for l, line in enumerate(code[line_number - 1 :], line_number):
-                if line.strip().startswith("def") or line.strip().startswith("class"):
-                    line_number = l
-                    break
+        if not repl:
+            call_frame = inspect.currentframe().f_back
+            filename = call_frame.f_code.co_filename
+            if Path(filename).resolve() == main_file_resolved:
+                filename_name = ""
             else:
-                line_number += 1
+                filename_name = f"[{Path(filename).name}]"
+
+            if filename not in codes:
+                frame_info = inspect.getframeinfo(call_frame, context=1000000)  # get the full source code
+                if frame_info.code_context is None:
+                    no_source_error()
+                codes[filename] = frame_info.code_context
+            code = codes[filename]
+            frame_info = inspect.getframeinfo(call_frame, context=1)
+            parent_function = frame_info.function
+            if parent_function == "<module>":
+                parent_function = ""
+            else:
+                parent_function = f" in {parent_function}()"
+            line_number = frame_info.lineno
+            if 0 <= line_number-1 < len(code):
+                this_line = code[line_number - 1].strip()
+            else:
+                this_line = ""
+            if 0 <= line_number-2 < len(code):
+                this_line_prev = code[line_number - 2].strip()
+            else:
+                this_line_prev = ""
+            if this_line.startswith("@") or this_line_prev.startswith("@"):
+                if as_str:
+                    raise TypeError("as_str may not be True when y used as decorator")
+                for l, line in enumerate(code[line_number - 1 :], line_number):
+                    if line.strip().startswith("def") or line.strip().startswith("class"):
+                        line_number = l
+                        break
+                else:
+                    line_number += 1
+                this.line_number_with_filename_and_parent = f"#{line_number}{filename_name}{parent_function}"
+
+                def real_decorator(function):
+                    @functools.wraps(function)
+                    def wrapper(*args, **kwargs):
+                        enter_time = time.perf_counter()
+                        context = this.context()
+
+                        args_kwargs = [repr(arg) for arg in args] + [f"{str(k)}={repr(v)}" for k, v in kwargs.items()]
+                        function_arguments = f"{function.__name__}({', '.join(args_kwargs)})"
+
+                        if this.show_enter:
+                            this.do_output(f"{context}called {function_arguments}")
+                        result = function(*args, **kwargs)
+                        duration = time.perf_counter() - enter_time
+
+                        context = this.context()
+                        if this.show_exit:
+                            this.do_output(f"{context}returned {repr(result)} from {function_arguments} in {duration:.6f} seconds")
+                        return result
+
+                    return wrapper
+
+                if len(args) == 0:
+                    return real_decorator
+
+                if len(args) == 1 and callable(args[0]):
+                    return real_decorator(args[0])
+                raise TypeError("arguments are not allowed in y used as decorator")
+
+            call_node = Source.executing(call_frame).node
+            if call_node is None:
+                no_source_error()
+            line_number = call_node.lineno
+            this_line = code[line_number - 1].strip()
+
             this.line_number_with_filename_and_parent = f"#{line_number}{filename_name}{parent_function}"
 
-            def real_decorator(function):
-                @functools.wraps(function)
-                def wrapper(*args, **kwargs):
-                    enter_time = time.perf_counter()
-                    context = this.context()
+            if this_line.startswith("with ") or this_line.startswith("with\t"):
+                if as_str:
+                    raise TypeError("as_str may not be True when y used as context manager")
+                if args:
+                    raise TypeError("non-keyword arguments are not allowed when y used as context manager")
 
-                    args_kwargs = [repr(arg) for arg in args] + [f"{str(k)}={repr(v)}" for k, v in kwargs.items()]
-                    function_arguments = f"{function.__name__}({', '.join(args_kwargs)})"
-
-                    if this.show_enter:
-                        this.do_output(f"{context}called {function_arguments}")
-                    result = function(*args, **kwargs)
-                    duration = time.perf_counter() - enter_time
-
-                    context = this.context()
-                    if this.show_exit:
-                        this.do_output(f"{context}returned {repr(result)} from {function_arguments} in {duration:.6f} seconds")
-                    return result
-
-                return wrapper
-
-            if len(args) == 0:
-                return real_decorator
-
-            if len(args) == 1 and callable(args[0]):
-                return real_decorator(args[0])
-            raise TypeError("arguments are not allowed in y used as decorator")
-
-        call_node = Source.executing(call_frame).node
-        if call_node is None:
-            no_source_error()
-        line_number = call_node.lineno
-        this_line = code[line_number - 1].strip()
-
-        this.line_number_with_filename_and_parent = f"#{line_number}{filename_name}{parent_function}"
-
-        if this_line.startswith("with ") or this_line.startswith("with\t"):
-            if as_str:
-                raise TypeError("as_str may not be True when y used as context manager")
-            if args:
-                raise TypeError("non-keyword arguments are not allowed when y used as context manager")
-
-            this.is_context_manager = True
-            return this
+                this.is_context_manager = True
+                return this
+        
+        if (not this.enabled or not global_enabled) and not as_str:
+            return return_args(args)
 
         if args:
             context = this.context()
-            source = Source.for_frame(call_frame)
             pairs = []
-            for node, right in zip(call_node.args, args):
-                left = source.asttokens().get_text(node)
-                if "\n" in left:
-                    left = " " * node.first_token.start[1] + left
-                    left = textwrap.dedent(left)
+            if repl or this.values_only:
+                for right in args:
+                    pairs.append(Pair(left="", right=right))
+            else:
+                source = Source.for_frame(call_frame)
+                for node, right in zip(call_node.args, args):
+                    left = source.asttokens().get_text(node)
+                    if "\n" in left:
+                        left = " " * node.first_token.start[1] + left
+                        left = textwrap.dedent(left)
 
-                try:
-                    ast.literal_eval(left)  # it's indeed a literal
-                    left = ""
-                except ValueError:
-                    left = left + ": "  # not a literal\
-                pairs.append(Pair(left=left, right=right))
+                    try:
+                        ast.literal_eval(left)  # it's indeed a literal
+                        left = ""
+                    except Exception:
+                        left = left + ": "  # not a literal\
+                    pairs.append(Pair(left=left, right=right))
 
             just_one_line = False
             if not any("\n" in pair.left for pair in pairs):
@@ -295,9 +329,13 @@ class Y:
                     just_one_line = True
 
             if not just_one_line:
+                if isinstance(this.wrap_indent, numbers.Number):
+                    wrap_indent = int(this.wrap_indent) * " "
+                else:
+                    wrap_indent = str(this.wrap_indent)
 
                 if context.strip():
-                    indent1 = this.wrap_indent
+                    indent1 = wrap_indent
                     lines = [context]
                 else:
                     indent1 = ""
@@ -318,7 +356,7 @@ class Y:
                         else:
                             lines.append(line)
                     if do_right:
-                        indent2 = indent1 + this.wrap_indent
+                        indent2 = indent1 + wrap_indent
                         line = this.serialize_kwargs(obj=pair.right, width=this.line_length - len(indent2))
                         for s in line.splitlines():
                             lines.append(indent2 + s)
@@ -329,15 +367,11 @@ class Y:
             this.show_line_number = True
             out = this.context(omit_context_delimiter=True)
 
-        if as_str:
+        if as_str:     
             return out + "\n"
         this.do_output(out)
 
-        if len(args) == 0:
-            return None
-        if len(args) == 1:
-            return args[0]
-        return args
+        return return_args(args)
 
     def configure(
         self,
@@ -358,7 +392,8 @@ class Y:
         depth=None,
         wrap_indent=None,
         context_delimiter=None,
-        pair_delimiter=None
+        pair_delimiter=None,
+        values_only=None,
     ):
         assign(self, locals(), self)
         check_output(self.output)
@@ -386,7 +421,8 @@ class Y:
         depth=None,
         wrap_indent=None,
         context_delimiter=None,
-        pair_delimiter=None
+        pair_delimiter=None,
+        values_only=None
     ):
         kwargs = {}
         assign(kwargs, locals(), self)
@@ -424,7 +460,7 @@ class Y:
         delattr(self, "is_context_manager")
 
     def context(self, omit_context_delimiter=False):
-        if self.show_line_number:
+        if self.show_line_number and not repl:
             parts = [self.line_number_with_filename_and_parent]
         else:
             parts = []
@@ -481,11 +517,14 @@ def enable(value=None):
         global_enabled = value
     return global_enabled
 
-
-global_enabled = True
-main_file_resolved = Path(sys.modules["__main__"].__file__).resolve()
-
 codes = {}
+global_enabled = True
+
+try:
+    main_file_resolved = Path(sys.modules["__main__"].__file__).resolve()
+except AttributeError:
+    main_file_resolved = None
+repl = main_file_resolved is None
 
 set_defaults()
 
